@@ -147,9 +147,9 @@ void DateNavigatorContainer::updateConfig()
 void DateNavigatorContainer::selectDates(const KCalendarCore::DateList &dateList, const QDate &preferredMonth)
 {
     if (!dateList.isEmpty()) {
-        QDate start(dateList.first());
-        QDate end(dateList.last());
-        QDate navfirst(mNavigatorView->startDate());
+        QDate const start(dateList.first());
+        QDate const end(dateList.last());
+        QDate const navfirst(mNavigatorView->startDate());
         QDate navsecond; // start of the second shown month if existent
         QDate navlast;
         if (!mExtraViews.isEmpty()) {
@@ -202,27 +202,27 @@ void DateNavigatorContainer::setBaseDates(const QDate &start)
 
 void DateNavigatorContainer::resizeEvent(QResizeEvent *)
 {
-#if 0
-    qCDebug(KORGANIZER_LOG) << "DateNavigatorContainer::resizeEvent()";
-    qCDebug(KORGANIZER_LOG) << "  CURRENT SIZE:" << size();
-    qCDebug(KORGANIZER_LOG) << "  MINIMUM SIZEHINT:" << minimumSizeHint();
-    qCDebug(KORGANIZER_LOG) << "  SIZEHINT:" << sizeHint();
-    qCDebug(KORGANIZER_LOG) << "  MINIMUM SIZE:" << minimumSize();
-#endif
+    /*
+        qCDebug(KORGANIZER_LOG) << "DateNavigatorContainer::resizeEvent()";
+        qCDebug(KORGANIZER_LOG) << "  CURRENT SIZE:" << size();
+        qCDebug(KORGANIZER_LOG) << "  MINIMUM SIZEHINT:" << minimumSizeHint();
+        qCDebug(KORGANIZER_LOG) << "  SIZEHINT:" << sizeHint();
+        qCDebug(KORGANIZER_LOG) << "  MINIMUM SIZE:" << minimumSize();
+    */
     QTimer::singleShot(0, this, &DateNavigatorContainer::resizeAllContents);
 }
 
 void DateNavigatorContainer::resizeAllContents()
 {
-    QSize minSize = mNavigatorView->minimumSizeHint();
+    QSize const minSize = mNavigatorView->minimumSizeHint();
 
     //  qCDebug(KORGANIZER_LOG) << "  NAVIGATORVIEW minimumSizeHint:" << minSize;
 
-    int verticalCount = size().height() / minSize.height();
-    int horizontalCount = size().width() / minSize.width();
+    int const verticalCount = size().height() / minSize.height();
+    int const horizontalCount = size().width() / minSize.width();
 
     if (horizontalCount != mHorizontalCount || verticalCount != mVerticalCount) {
-        int count = horizontalCount * verticalCount;
+        int const count = horizontalCount * verticalCount;
         if (count == 0) {
             return;
         }
@@ -230,7 +230,7 @@ void DateNavigatorContainer::resizeAllContents()
         while (count > (mExtraViews.count() + 1)) {
             auto n = new KDateNavigator(this);
             mExtraViews.append(n);
-            for (const auto &calendar : mCalendars) {
+            for (const auto &calendar : std::as_const(mCalendars)) {
                 n->addCalendar(calendar);
             }
             connectNavigatorView(n);
@@ -255,8 +255,8 @@ void DateNavigatorContainer::resizeAllContents()
         }
     }
 
-    int height = size().height() / verticalCount;
-    int width = size().width() / horizontalCount;
+    int const height = size().height() / verticalCount;
+    int const width = size().width() / horizontalCount;
 
     NavigatorBar *bar = mNavigatorView->navigatorBar();
     if (horizontalCount > 1) {
@@ -267,8 +267,8 @@ void DateNavigatorContainer::resizeAllContents()
 
     mNavigatorView->setGeometry((((KOGlobals::self()->reverseLayout()) ? (horizontalCount - 1) : 0) * width), 0, width, height);
     for (int i = 0; i < mExtraViews.count(); ++i) {
-        int x = (i + 1) % horizontalCount;
-        int y = (i + 1) / horizontalCount;
+        int const x = (i + 1) % horizontalCount;
+        int const y = (i + 1) / horizontalCount;
 
         KDateNavigator *view = mExtraViews.at(i);
         bar = view->navigatorBar();
@@ -299,7 +299,7 @@ void DateNavigatorContainer::setHighlightMode(bool highlightEvents, bool highlig
 {
     mNavigatorView->setHighlightMode(highlightEvents, highlightTodos, highlightJournals);
 
-    for (KDateNavigator *n : std::as_const(mExtraViews)) {
+    for (const KDateNavigator *n : std::as_const(mExtraViews)) {
         if (n) {
             n->setHighlightMode(highlightEvents, highlightTodos, highlightJournals);
         }
@@ -333,10 +333,10 @@ QPair<QDate, QDate> DateNavigatorContainer::dateLimits(int offset) const
     firstMonth = mNavigatorView->month().addMonths(offset);
     lastMonth = lastMonth.addMonths(offset);
 
-    QPair<QDate, QDate> firstMonthBoundary = KODayMatrix::matrixLimits(firstMonth);
-    QPair<QDate, QDate> lastMonthBoundary = KODayMatrix::matrixLimits(lastMonth);
+    KODayMatrix::MatrixRange const firstMonthBoundary = KODayMatrix::matrixLimits(firstMonth);
+    KODayMatrix::MatrixRange const lastMonthBoundary = KODayMatrix::matrixLimits(lastMonth);
 
-    return qMakePair(firstMonthBoundary.first, lastMonthBoundary.second);
+    return qMakePair(firstMonthBoundary.start, lastMonthBoundary.end);
 }
 
 QDate DateNavigatorContainer::monthOfNavigator(int navigatorIndex) const
@@ -379,16 +379,16 @@ KDateNavigator *DateNavigatorContainer::firstNavigatorForDate(const QDate &date)
 {
     KDateNavigator *navigator = nullptr;
     if (date.isValid()) {
-        QPair<QDate, QDate> limits = KODayMatrix::matrixLimits(mNavigatorView->month());
+        KODayMatrix::MatrixRange limits = KODayMatrix::matrixLimits(mNavigatorView->month());
 
-        if (date >= limits.first && date <= limits.second) {
+        if (date >= limits.start && date <= limits.end) {
             // The date is in the first navigator
             navigator = mNavigatorView;
         } else {
             for (KDateNavigator *nav : std::as_const(mExtraViews)) {
                 if (nav) {
                     limits = KODayMatrix::matrixLimits(nav->month());
-                    if (date >= limits.first && date <= limits.second) {
+                    if (date >= limits.start && date <= limits.end) {
                         navigator = nav;
                         break;
                     }
